%define oname	gstreamer
%define api	1.0

%define major		0
%define libname		%mklibname %{oname} %{api} %{major}
%define gi_name		%mklibname gst-gir %{api}
%define libnamedev	%mklibname %{name} -d

# Disabled as we don't have hotdoc
%bcond_with docs

# Disabled tests
%bcond_with tests

Name:		%{oname}%{api}
Summary:	GStreamer Streaming-media framework runtime
Version:	1.24.1
Release:	%mkrel 1
License:	LGPLv2+
Group:		System/Libraries
URL:		https://gstreamer.freedesktop.org/
Source0: 	https://gstreamer.freedesktop.org/src/gstreamer/%{oname}-%{version}.tar.xz
## For GStreamer RPM provides
Source1:	gstreamer1.prov
Source2:	gstreamer1.attr
Patch0:		0001-gst-inspect-add-mode-to-output-RPM-requires-format.patch
# upstream patchset, from https://gitlab.freedesktop.org/gstreamer/gstreamer/
#
BuildRequires:	pkgconfig(bash-completion)
BuildRequires:	pkgconfig(gio-2.0)
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(gmodule-no-export-2.0)
BuildRequires:	pkgconfig(gobject-2.0)
BuildRequires:	pkgconfig(gthread-2.0)
BuildRequires:	pkgconfig(gtk+-3.0)
BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:	pkgconfig(libunwind)
BuildRequires:	pkgconfig(libdw)
BuildRequires:	pkgconfig(gmp)
BuildRequires:	pkgconfig(gsl)
BuildRequires:	pkgconfig(gobject-introspection-1.0)
BuildRequires:	pkgconfig(popt)
BuildRequires:	gettext-devel
BuildRequires:	pkgconfig(check)
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	meson
BuildRequires:	rustc
# for setcap
BuildRequires:	pkgconfig(libcap)
BuildRequires:	libcap-utils
%ifarch %{valgrind_arches} %{arm32}
BuildRequires:	pkgconfig(valgrind)
%endif

%ifarch %ix86
BuildRequires:	nasm >= 0.90
%endif

%if %{with docs}
BuildRequires:	gtk-doc
BuildRequires:	transfig
BuildRequires:	docbook-dtd42-xml
BuildRequires:	docbook-dtd412-xml
BuildRequires:	ghostscript
%endif

%if %{with tests}
BuildRequires:	x11-server-xvfb
%endif

%description
GStreamer is a streaming-media framework, based on graphs of filters which
operate on media data. Applications using this library can do anything
from real-time sound processing to playing videos, and just about anything
else media-related.  Its plugin-based architecture means that new data
types or processing capabilities can be added simply by installing new
plugins.

%package tools
Summary:	GStreamer Streaming-media framework runtime
Group:		System/Libraries
Conflicts:	%{_lib}gstreamer1.0_0 < 1.16.2-3

%description tools
GStreamer is a streaming-media framework, based on graphs of filters which
operate on media data. Applications using this library can do anything
from real-time sound processing to playing videos, and just about anything
else media-related.  Its plugin-based architecture means that new data
types or processing capabilities can be added simply by installing new
plugins.

%package -n %{libname}
Summary:	Libraries for GStreamer streaming-media framework
Group:		System/Libraries
Requires:	%{name}-tools >= %{version}-%{release}
Provides:	libgstreamer%{api} = %{version}-%{release}

%description -n %{libname}
GStreamer is a streaming-media framework, based on graphs of filters which
operate on media data. Applications using this library can do anything
from real-time sound processing to playing videos, and just about anything
else media-related.  Its plugin-based architecture means that new data
types or processing capabilities can be added simply by installing new
plugins.

This package contains the libraries.

%package -n %{gi_name}
Summary:	GObject Introspection interface libraries for %{name}
Group:		System/Libraries
Requires:	%{libname} = %{version}-%{release}

%description -n %{gi_name}
GObject Introspection interface libraries for %{name}.

%package -n %{libnamedev}
Summary:	Libraries and include files for GStreamer streaming-media framework
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Requires:	%{gi_name} = %{version}-%{release}
Requires:	%{name}-tools = %{version}-%{release}
Provides:	gstreamer%{api}-devel = %{version}-%{release}
Conflicts:	%{_lib}gstreamer-plugins-bad1.0-devel < 1.14.0

%description -n %{libnamedev}
GStreamer is a streaming-media framework, based on graphs of filters which
operate on media data. Applications using this library can do anything
from real-time sound processing to playing videos, and just about anything
else media-related.  Its plugin-based architecture means that new data
types or processing capabilities can be added simply by installing new
plugins.

This package contains the libraries and includes files necessary to develop
applications and plugins for GStreamer.

%prep
%autosetup -p3 -n %{oname}-%{version}

%build
%meson \
	-Dptp-helper-permissions=capabilities \
	-Dlibunwind=enabled \
	-Dlibdw=enabled \
	-Ddbghelp=disabled \
	-Dbash-completion=enabled \
	-Dexamples=disabled \
%if %{with tests}
	-Dtests=enabled \
%else
	-Dtests=disabled \
%endif
	-Dbenchmarks=enabled \
	-Dtools=enabled \
	-Ddoc=%{?_with_docs:enabled}%{?!_with_docs:disabled} \
	-Dintrospection=enabled \
	-Dgobject-cast-checks=disabled \
	-Dglib-asserts=disabled \
	-Dglib-checks=disabled \
	-Dpackage-name='%{_vendor} %{name} package' \
	-Dpackage-origin='https://www.%{_real_vendor}.org/'
%meson_build

%install
%meson_install

mkdir -p %{buildroot}%{_var}/cache/%{oname}-%{api}

#clean the files we don't want to install
find %{buildroot} -name '*.la' -delete

%find_lang %{oname}-%{api}

# Add the provides script
install -m0755 -D %{SOURCE1} %{buildroot}%{_rpmconfigdir}/gstreamer1.prov

# Add the gstreamer plugin file attribute entry (rpm >= 4.9.0)
install -m0755 -D %{SOURCE2} %{buildroot}%{_rpmconfigdir}/fileattrs/gstreamer1.attr

%check
%if %{with tests}
export XDG_RUNTIME_DIR="$(pwd)/runtime-dir"
mkdir -p -m 700 "$XDG_RUNTIME_DIR"
xvfb-run -s '-nolisten local' \
        meson test -C %{_vpath_builddir} --print-errorlogs -t 3 
%endif

%files tools -f %{oname}-%{api}.lang
%license COPYING
%doc AUTHORS README.md NEWS
%dir %{_var}/cache/%{oname}-%{api}
%{_bindir}/gst-inspect-%{api}
%{_bindir}/gst-launch-%{api}
%{_bindir}/gst-typefind-%{api}
%{_bindir}/gst-stats-%{api}
%{_mandir}/man1/gst-inspect-%{api}.1*
%{_mandir}/man1/gst-launch-%{api}.1*
%{_mandir}/man1/gst-typefind-%{api}.1*
%{_mandir}/man1/gst-stats-%{api}.1*
%{_datadir}/bash-completion/completions/gst-inspect-1.0
%{_datadir}/bash-completion/completions/gst-launch-1.0
%{_datadir}/bash-completion/helpers/gst
%dir %{_libexecdir}/%{oname}-%{api}/
%caps(cap_sys_nice,cap_net_bind_service,cap_net_admin+ep) %{_libexecdir}/%{oname}-%{api}/gst-ptp-helper
%{_libexecdir}/%{oname}-%{api}/gst-completion-helper
%{_libexecdir}/%{oname}-%{api}/gst-plugin-scanner
%{_libexecdir}/%{oname}-%{api}/gst-hotdoc-plugins-scanner
%{_libexecdir}/%{oname}-%{api}/gst-plugins-doc-cache-generator

%files -n %{libname}
%dir %{_libdir}/%{oname}-%{api}
%{_libdir}/libgstbase-%{api}.so.%{major}{,.*}
%{_libdir}/libgstcheck-%{api}.so.%{major}{,.*}
%{_libdir}/libgstreamer-%{api}.so.%{major}{,.*}
%{_libdir}/libgstnet-%{api}.so.%{major}{,.*}
%{_libdir}/libgstcontroller-%{api}.so.%{major}{,.*}
%{_libdir}/%{oname}-%{api}/libgstcoreelements.so
%{_libdir}/%{oname}-%{api}/libgstcoretracers.so

%files -n %{gi_name}
%{_libdir}/girepository-1.0/Gst-%{api}.typelib
%{_libdir}/girepository-1.0/GstBase-%{api}.typelib
%{_libdir}/girepository-1.0/GstCheck-%{api}.typelib
%{_libdir}/girepository-1.0/GstController-%{api}.typelib
%{_libdir}/girepository-1.0/GstNet-%{api}.typelib

%files -n %{libnamedev}
%doc ChangeLog
%if %{with docs}
## gstreamer API
%doc %{_datadir}/gtk-doc/html/%{oname}/
## gstreamer-libs API
%doc %{_datadir}/gtk-doc/html/%{oname}-libs/
%endif

%{_rpmconfigdir}/gstreamer1.prov
%{_rpmconfigdir}/fileattrs/gstreamer1.attr
%dir %{_includedir}/%{oname}-%{api}
%dir %{_includedir}/%{oname}-%{api}/gst
%{_includedir}/%{oname}-%{api}/gst/*.h
%dir %{_includedir}/%{oname}-%{api}/gst/base/
%{_includedir}/%{oname}-%{api}/gst/base/*.h
%{_includedir}/%{oname}-%{api}/gst/check/
%dir %{_includedir}/%{oname}-%{api}/gst/controller/
%{_includedir}/%{oname}-%{api}/gst/controller/*.h
%{_includedir}/%{oname}-%{api}/gst/net/
%{_libdir}/libgstbase-%{api}.so
%{_libdir}/libgstcheck-%{api}.so
%{_libdir}/libgstreamer-%{api}.so
%{_libdir}/libgstnet-%{api}.so
%{_libdir}/libgstcontroller-%{api}.so
%{_datadir}/aclocal/gst-element-check-%{api}.m4
%{_libdir}/pkgconfig/gstreamer-%{api}.pc
%{_libdir}/pkgconfig/gstreamer-base-%{api}.pc
%{_libdir}/pkgconfig/gstreamer-check-%{api}.pc
%{_libdir}/pkgconfig/gstreamer-net-%{api}.pc
%{_libdir}/pkgconfig/gstreamer-controller-%{api}.pc
%{_datadir}/gir-1.0/Gst-%{api}.gir
%{_datadir}/gir-1.0/GstBase-%{api}.gir
%{_datadir}/gir-1.0/GstCheck-%{api}.gir
%{_datadir}/gir-1.0/GstController-%{api}.gir
%{_datadir}/gir-1.0/GstNet-%{api}.gir

# gdb extension
%{_datadir}/gdb/auto-load%{_libdir}/*.py
%dir %{_datadir}/gstreamer-1.0/
%{_datadir}/gstreamer-1.0/gdb/


%changelog
* Mon Mar 25 2024 daviddavid <daviddavid> 1.24.1-1.mga10
+ Revision: 2052104
- new version 1.24.1

* Sun Mar 24 2024 wally <wally> 1.24.0-2.mga10
+ Revision: 2051854
- add missing cap_sys_nice capability to gst-ptp-helper

* Sun Mar 24 2024 daviddavid <daviddavid> 1.24.0-1.mga10
+ Revision: 2051844
- new version 1.24.0

* Sun Feb 04 2024 wally <wally> 1.22.9-4.mga10
+ Revision: 2037137
- one more rebuild for arm32

* Sun Feb 04 2024 wally <wally> 1.22.9-3.mga10
+ Revision: 2037133
- another rebuild for arm32

* Sun Feb 04 2024 wally <wally> 1.22.9-2.mga10
+ Revision: 2037080
- rebuild for arm32

* Mon Jan 29 2024 wally <wally> 1.22.9-1.mga10
+ Revision: 2036089
- new version 1.22.9

* Mon Jan 08 2024 daviddavid <daviddavid> 1.22.8-3.mga10
+ Revision: 2029050
- really rebuild for arm

* Mon Jan 08 2024 daviddavid <daviddavid> 1.22.8-2.mga10
+ Revision: 2029013
- rebuild for arm

* Wed Dec 20 2023 ghibo <ghibo> 1.22.8-1.mga10
+ Revision: 2020039
- Update to release 1.22.8

* Mon Oct 09 2023 wally <wally> 1.22.6-1.mga10
+ Revision: 1993806
- new version 1.22.6

* Tue Aug 29 2023 ghibo <ghibo> 1.22.5-1.mga10
+ Revision: 1980850
- Update to release 1.22.5

* Sat Jul 08 2023 ghibo <ghibo> 1.22.4-1.mga9
+ Revision: 1963692
- Update to release 1.22.4

* Sun May 21 2023 ghibo <ghibo> 1.22.3-1.mga9
+ Revision: 1957534
- Update to release 1.22.3.
- Add patch to build executables with PIE.
- Add support for check in SPEC file.

* Tue Jan 24 2023 wally <wally> 1.22.0-1.mga9
+ Revision: 1935694
- new version 1.22.0

* Sat Jan 14 2023 wally <wally> 1.21.90-1.mga9
+ Revision: 1933038
- new version 1.21.90

* Mon Dec 26 2022 wally <wally> 1.20.5-1.mga9
+ Revision: 1926949
- new version 1.20.5

* Sun Nov 20 2022 wally <wally> 1.20.4-1.mga9
+ Revision: 1909308
- new version 1.20.4

* Sat Jul 23 2022 wally <wally> 1.20.3-2.mga9
+ Revision: 1870429
- rebuild for core/release

* Sat Jul 23 2022 wally <wally> 1.20.3-1.mga9
+ Revision: 1870390
- new version 1.20.3

* Sun May 08 2022 wally <wally> 1.20.2-1.mga9
+ Revision: 1856814
- new version 1.20.2

* Sun Apr 03 2022 wally <wally> 1.20.1-1.mga9
+ Revision: 1841853
- new version 1.20.1

* Sat Apr 02 2022 umeabot <umeabot> 1.18.5-2.mga9
+ Revision: 1840455
- Mageia 9 Mass Rebuild

* Wed Sep 15 2021 neoclust <neoclust> 1.18.5-1.mga9
+ Revision: 1745533
- New version 1.18.5

* Mon Apr 05 2021 wally <wally> 1.18.4-1.mga9
+ Revision: 1713698
- new version 1.18.4

* Mon Jan 18 2021 wally <wally> 1.18.3-1.mga8
+ Revision: 1672329
- new version 1.18.3

* Wed Dec 09 2020 wally <wally> 1.18.2-1.mga8
+ Revision: 1655015
- new version 1.18.2

* Sat Nov 21 2020 wally <wally> 1.18.1-1.mga8
+ Revision: 1648084
- new version 1.18.1

* Sun Sep 13 2020 wally <wally> 1.18.0-1.mga8
+ Revision: 1625662
- new version 1.18.0

* Tue Feb 18 2020 umeabot <umeabot> 1.16.2-4.mga8
+ Revision: 1541563
- Mageia 8 Mass Rebuild

* Sun Dec 29 2019 wally <wally> 1.16.2-3.mga8
+ Revision: 1474755
- switch to meson build
- move gst-plugin-scanner to utils pkg

* Sun Dec 29 2019 wally <wally> 1.16.2-2.mga8
+ Revision: 1474715
- add capabilities for gst-ptp-helper

* Wed Dec 04 2019 ovitters <ovitters> 1.16.2-1.mga8
+ Revision: 1464178
- new version 1.16.2

* Mon Sep 23 2019 ovitters <ovitters> 1.16.1-1.mga8
+ Revision: 1445151
- new version 1.16.1

* Thu Apr 25 2019 wally <wally> 1.16.0-2.mga7
+ Revision: 1395296
- sync gstreamer1.prov with Fedora

* Thu Apr 25 2019 wally <wally> 1.16.0-1.mga7
+ Revision: 1395265
- new version 1.16.0
- rediff gst-inspect rpm format patch

* Thu Oct 04 2018 ovitters <ovitters> 1.14.4-1.mga7
+ Revision: 1317441
- new version 1.14.4

* Mon Sep 17 2018 ovitters <ovitters> 1.14.3-1.mga7
+ Revision: 1259412
- new version 1.14.3

* Fri Jul 20 2018 ovitters <ovitters> 1.14.2-1.mga7
+ Revision: 1244436
- new version 1.14.2

* Mon May 21 2018 wally <wally> 1.14.1-1.mga7
+ Revision: 1231132
- new version 1.14.1

* Mon May 21 2018 wally <wally> 1.14.0-3.mga7
+ Revision: 1231127
- fix gst rpm provides generator after output change in file >= 5.33

* Sat Mar 24 2018 wally <wally> 1.14.0-2.mga7
+ Revision: 1212054
- add conflicts as files moved between pkgs

* Sat Mar 24 2018 wally <wally> 1.14.0-1.mga7
+ Revision: 1211999
- new version 1.14.0
- rediff P0
- enable valgrind support for all valgrind supported arches

* Sat Dec 16 2017 wally <wally> 1.12.4-2.mga7
+ Revision: 1182804
- disable valgrind support on arm for now

* Sat Dec 16 2017 wally <wally> 1.12.4-1.mga7
+ Revision: 1182795
- new version 1.12.4

* Sat Sep 23 2017 ovitters <ovitters> 1.12.3-1.mga7
+ Revision: 1157976
- new version 1.12.3

* Wed Jul 26 2017 wally <wally> 1.12.2-2.mga7
+ Revision: 1131279
- build with libdw to add source lines and numbers to backtraces

* Mon Jul 24 2017 wally <wally> 1.12.2-1.mga7
+ Revision: 1130298
- new version 1.12.2
- rediff P0

* Mon Jul 17 2017 ovitters <ovitters> 1.10.5-1.mga7
+ Revision: 1124551
- new version 1.10.5

* Thu Feb 23 2017 ovitters <ovitters> 1.10.4-1.mga6
+ Revision: 1087468
- new version 1.10.4

* Mon Jan 30 2017 ovitters <ovitters> 1.10.3-1.mga6
+ Revision: 1084207
- new version 1.10.3

* Sun Jan 15 2017 wally <wally> 1.10.2-1.mga6
+ Revision: 1081793
- new version 1.10.2
- BR libunwind

* Fri Aug 19 2016 luigiwalser <luigiwalser> 1.8.3-1.mga6
+ Revision: 1047091
- 1.8.3

* Fri Jun 10 2016 luigiwalser <luigiwalser> 1.8.2-1.mga6
+ Revision: 1020999
- 1.8.2

* Wed Apr 20 2016 ovitters <ovitters> 1.8.1-1.mga6
+ Revision: 1003812
- new version 1.8.1

* Thu Mar 24 2016 ovitters <ovitters> 1.8.0-1.mga6
+ Revision: 994924
- new version 1.8.0

* Tue Mar 15 2016 ovitters <ovitters> 1.7.91-1.mga6
+ Revision: 990918
- new version 1.7.91

* Tue Mar 01 2016 ovitters <ovitters> 1.7.90-1.mga6
+ Revision: 981725
- new version 1.7.90
- rediff patch

* Sat Jan 23 2016 luigiwalser <luigiwalser> 1.6.3-1.mga6
+ Revision: 926680
- 1.6.3

* Mon Dec 14 2015 ovitters <ovitters> 1.6.2-1.mga6
+ Revision: 910464
- new version 1.6.2
+ tv <tv>
- switch to pkgconfig() BRs

* Fri Oct 30 2015 ovitters <ovitters> 1.6.1-1.mga6
+ Revision: 896740
- new version 1.6.1

* Sat Sep 26 2015 tv <tv> 1.6.0-2.mga6
+ Revision: 884032
- adjust file list on ia32
- adjust file list
- new release

* Mon Jun 29 2015 wally <wally> 1.4.5-2.mga6
+ Revision: 847477
- add requires for gir pkg to devel pkg

* Sun Jun 21 2015 luigiwalser <luigiwalser> 1.4.5-1.mga6
+ Revision: 836945
- 1.4.5

* Sat Jun 20 2015 ovitters <ovitters> 1.4.4-1.mga6
+ Revision: 836282
- new version 1.4.4

* Wed Oct 15 2014 umeabot <umeabot> 1.4.3-2.mga5
+ Revision: 748604
- Second Mageia 5 Mass Rebuild

* Sun Sep 28 2014 wally <wally> 1.4.3-1.mga5
+ Revision: 731363
- new version 1.4.3

* Sun Sep 28 2014 tv <tv> 1.4.1-5.mga5
+ Revision: 731159
- rebuild so that it picks typelib() requires

* Tue Sep 16 2014 umeabot <umeabot> 1.4.1-4.mga5
+ Revision: 679981
- Mageia 5 Mass Rebuild

* Mon Sep 08 2014 tv <tv> 1.4.1-3.mga5
+ Revision: 673765
- adjust file list
- add RPM dependency generators for gst

* Thu Aug 28 2014 ovitters <ovitters> 1.4.1-1.mga5
+ Revision: 668984
- new version 1.4.1

* Tue Jul 29 2014 tv <tv> 1.4.0-2.mga5
+ Revision: 657827
- rebuild with fixed gcc (might fix ff & shotwell)

* Mon Jul 21 2014 fwang <fwang> 1.4.0-1.mga5
+ Revision: 654935
- update file list
- 1.4.0

* Sat Apr 19 2014 fwang <fwang> 1.2.4-1.mga5
+ Revision: 616972
- 1.2.4

* Sun Feb 09 2014 fwang <fwang> 1.2.3-1.mga5
+ Revision: 587301
- 1.2.3

* Thu Jan 23 2014 gw666 <gw666> 1.2.2-1.mga4
+ Revision: 567574
- new version (bug #12142)

* Sat Oct 19 2013 umeabot <umeabot> 1.2.0-2.mga4
+ Revision: 536674
- Mageia 4 Mass Rebuild

* Tue Sep 24 2013 ovitters <ovitters> 1.2.0-1.mga4
+ Revision: 485281
- new version 1.2.0

* Sat Sep 21 2013 fwang <fwang> 1.1.90-1.mga4
+ Revision: 483004
- new version 1.1.90

* Thu Aug 29 2013 fwang <fwang> 1.0.10-1.mga4
+ Revision: 472788
- new version 1.0.10

* Thu Aug 01 2013 fwang <fwang> 1.0.9-1.mga4
+ Revision: 461930
- new version 1.0.9

* Fri Jul 12 2013 ovitters <ovitters> 1.0.8-1.mga4
+ Revision: 453545
- new version 1.0.8

* Fri May 24 2013 fwang <fwang> 1.0.7-1.mga4
+ Revision: 425846
- new version 1.0.7

* Sat Jan 12 2013 umeabot <umeabot> 1.0.5-2.mga3
+ Revision: 352753
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 09 2013 fwang <fwang> 1.0.5-1.mga3
+ Revision: 343502
- new version 1.0.5

* Sat Jan 05 2013 cjw <cjw> 1.0.4-2.mga3
+ Revision: 338820
- fix for libexecdir -> /usr/libexec : keep plugin scanner in libdir
- fix filelist for duplicate files
- regenerate build scripts with system autotools so we are sure this package builds from source
- patch1: fix build with automake 1.13

* Thu Dec 20 2012 cjw <cjw> 1.0.4-1.mga3
+ Revision: 333462
- 1.0.4

* Thu Nov 22 2012 fwang <fwang> 1.0.3-1.mga3
+ Revision: 320503
- new version 1.0.3

* Thu Oct 25 2012 ovitters <ovitters> 1.0.2-1.mga3
+ Revision: 309974
- new version 1.0.2

* Mon Oct 08 2012 fwang <fwang> 1.0.1-1.mga3
+ Revision: 303315
- update rpm group
+ ovitters <ovitters>
- new version 1.0.1

* Mon Sep 24 2012 fwang <fwang> 1.0.0-1.mga3
+ Revision: 297080
- new version 1.0.0

* Mon Sep 17 2012 ovitters <ovitters> 0.11.99-1.mga3
+ Revision: 295508
- new version 0.11.99

* Mon Sep 17 2012 fwang <fwang> 0.11.94-4.mga3
+ Revision: 295313
- rename rpm provides so that it does not conflict with gst0.10

* Sat Sep 15 2012 fwang <fwang> 0.11.94-3.mga3
+ Revision: 294170
- fix gstreamer.prov

* Sat Sep 15 2012 fwang <fwang> 0.11.94-2.mga3
+ Revision: 294169
- sync fedora patch on gstramer provides
+ ovitters <ovitters>
- clean spec

* Fri Sep 14 2012 fwang <fwang> 0.11.94-1.mga3
+ Revision: 293790
- new version 0.11.94

* Tue Sep 04 2012 fwang <fwang> 0.11.93-2.mga3
+ Revision: 287907
- disable check
- update libmajor

* Tue Sep 04 2012 fwang <fwang> 0.11.93-1.mga3
+ Revision: 287806
- new version 0.11.93
- disable gstream provides to wait fedora folks
- cleanup spec
+ dmorgan <dmorgan>
- imported package gstreamer1.0

